package com.example.demo.service;

import cn.afterturn.easypoi.excel.ExcelImportUtil;
import cn.afterturn.easypoi.excel.entity.ImportParams;
import cn.afterturn.easypoi.excel.entity.result.ExcelImportResult;
import com.example.demo.dto.ExampleData;
import com.example.demo.dto.R;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * @author guoxiang
 * @see <a href="https://www.jianshu.com/u/aba665c4151f">简书TinyThing</a>
 * @since 2022/7/21 13:43
 */
@Service
@Slf4j
public class DataService {

    /**
     * 导入数据
     * @param file excel文件
     * @return  结果
     */
    public R<List<ExampleData>> importData(MultipartFile file) {
        //导入的基本配置
        ImportParams params = new ImportParams();
        //代表导入这里是需要验证的（根据字段上的注解校验）
        params.setNeedVerify(true);
        params.setTitleRows(0);
        //使用框架自身导入工具
        ExcelImportResult<ExampleData> result;
        try {
            result = ExcelImportUtil.importExcelMore(file.getInputStream(), ExampleData.class, params);
        } catch (Exception e) {
            log.error("导入数据错误", e);
            throw new IllegalArgumentException();
        }

        //如果存在校验失败的数据，则返回给用户
        if (result.isVerifyFail()) {
            //失败结果集
            List<ExampleData> failList = result.getFailList();
            return R.failed(failList);
        }

        //校验成功的数据
        List<ExampleData> list = result.getList();
        //将数据保存到数据库
        saveToDataBase(list);

        return R.ok();
    }

    /**
     * 保存到数据库
     *
     * @param list 数据
     */
    private void saveToDataBase(List<ExampleData> list) {
        list.forEach(data -> log.info("data = {}", data));
    }
}
